.. DataVizML documentation master file, created by
   sphinx-quickstart on Wed Feb 15 12:31:35 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to DataVizML's documentation!
=====================================

``DataVizML`` is a high-level Object Orientated Python package which aims to provide an easy and intuitive way of exploring the distribution of a set of ML model features and their relationship to a proposed target

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   install
   datavizml
   demonstration
   related_reading

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
